package agent

import (
	"context"
	"database/sql"
	"github.com/pkg/errors"
	"tydata-server/app/user/model"
	"tydata-server/common/ctxdata"
	"tydata-server/common/xerr"
	"tydata-server/pkg/lzkit/lzUtils"

	"tydata-server/app/user/cmd/api/internal/svc"
	"tydata-server/app/user/cmd/api/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetAgentInfoLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewGetAgentInfoLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetAgentInfoLogic {
	return &GetAgentInfoLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *GetAgentInfoLogic) GetAgentInfo() (resp *types.AgentInfoResp, err error) {
	userID, err := ctxdata.GetUidFromCtx(l.ctx)
	if err != nil {
		return nil, errors.Wrapf(xerr.NewErrCode(xerr.SERVER_COMMON_ERROR), "获取代理信息, %v", err)
	}
	agent, err := l.svcCtx.AgentModel.FindOneByUserId(l.ctx, userID)
	if err != nil {
		if errors.Is(err, sql.ErrNoRows) {
			agentAuditModel, findAgentAuditErr := l.svcCtx.AgentAuditModel.FindOneByUserId(l.ctx, userID)
			if findAgentAuditErr != nil && !errors.Is(findAgentAuditErr, model.ErrNotFound) {
				return nil, errors.Wrapf(xerr.NewErrCode(xerr.DB_ERROR), "获取代理信息, %v", err)
			}
			if errors.Is(findAgentAuditErr, model.ErrNotFound) {
				return &types.AgentInfoResp{
					IsAgent: false,
					Status:  3,
				}, nil
			}
			return &types.AgentInfoResp{
				IsAgent: false,
				Status:  agentAuditModel.Status,
			}, nil
		}
		return nil, errors.Wrapf(xerr.NewErrCode(xerr.DB_ERROR), "获取代理信息, %v", err)
	}
	return &types.AgentInfoResp{
		AgentID:  agent.Id,
		Level:    agent.LevelName,
		IsAgent:  true,
		Status:   1,
		Region:   agent.Region,
		Mobile:   agent.Mobile,
		WechatID: lzUtils.NullStringToString(agent.WechatId),
	}, nil
}
