package agent

import (
	"context"
	"github.com/pkg/errors"
	"tydata-server/app/user/model"
	"tydata-server/common/ctxdata"
	"tydata-server/common/xerr"

	"tydata-server/app/user/cmd/api/internal/svc"
	"tydata-server/app/user/cmd/api/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type SaveAgentMembershipUserConfigLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewSaveAgentMembershipUserConfigLogic(ctx context.Context, svcCtx *svc.ServiceContext) *SaveAgentMembershipUserConfigLogic {
	return &SaveAgentMembershipUserConfigLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *SaveAgentMembershipUserConfigLogic) SaveAgentMembershipUserConfig(req *types.SaveAgentMembershipUserConfigReq) error {
	userID, err := ctxdata.GetUidFromCtx(l.ctx)
	if err != nil {
		return errors.Wrapf(xerr.NewErrCode(xerr.SERVER_COMMON_ERROR), "保存会员代理报告配置，获取用户ID失败: %v", err)
	}
	agentModel, err := l.svcCtx.AgentModel.FindOneByUserId(l.ctx, userID)
	if err != nil {
		return errors.Wrapf(xerr.NewErrCode(xerr.SERVER_COMMON_ERROR), "保存会员代理报告配置: %v", err)
	}
	agentMembershipUserConfigModel, err := l.svcCtx.AgentMembershipUserConfigModel.FindOneByAgentIdProductId(l.ctx, agentModel.Id, req.ProductID)
	if err != nil && !errors.Is(err, model.ErrNotFound) {
		return err
	}
	//err = copier.Copy(&agentMembershipUserConfigModel, &req)
	//if err != nil {
	//	return errors.Wrapf(xerr.NewErrCode(xerr.SERVER_COMMON_ERROR), "保存会员代理报告配置: %v", err)
	//}
	agentMembershipUserConfigModel.PriceRatio = req.PriceRatio
	agentMembershipUserConfigModel.PriceIncreaseAmount = req.PriceIncreaseAmount
	agentMembershipUserConfigModel.PriceRangeFrom = req.PriceRangeFrom
	agentMembershipUserConfigModel.PriceRangeTo = req.PriceRangeTo
	if agentMembershipUserConfigModel == nil {
		agentMembershipUserConfigModel.UserId = userID
		agentMembershipUserConfigModel.AgentId = agentModel.Id
		_, err = l.svcCtx.AgentMembershipUserConfigModel.Insert(l.ctx, nil, agentMembershipUserConfigModel)
		if err != nil {
			return errors.Wrapf(xerr.NewErrCode(xerr.SERVER_COMMON_ERROR), "保存会员代理报告配置: %v", err)
		}
	} else {
		_, err = l.svcCtx.AgentMembershipUserConfigModel.Update(l.ctx, nil, agentMembershipUserConfigModel)
		if err != nil {
			return errors.Wrapf(xerr.NewErrCode(xerr.SERVER_COMMON_ERROR), "保存会员代理报告配置: %v", err)
		}
	}

	return nil
}
